@@ -76,7 +76,7 @@ from de.setup_project import (
     code_file_version, pev_str, pev_val, project_env_vars)
 
 
-__version__ = '0.2.2'
+__version__ = '0.2.3'
 
 
 # --------------- global constants ------------------------------------------------------------------------------------
@@ -156,7 +156,7 @@ _RCS: Dict[str, Callable] = {}
 REGISTERED_TPL_PROJECTS: Dict[str, RegisteredTemplateProject] = {}  #: registered template projects
 
 REMOTE_CLASS_NAMES: Dict[str, str] = {}                     #: class names of all supported remote hosts
-REMOTE_REPO: Optional[Any] = None                           #: remote class instance (None for local=True actions)
+REMOTE_REPO: Optional[Any] = None                           #: remote class instance (None for local_action)
 
 TEMP_CONTEXT: Optional[tempfile.TemporaryDirectory] = None  #: temp patch folder context (optional/lazy/late created)
 TEMP_PARENT_FOLDER: str                                     #: temporary parent folder for to clone git repos into
@@ -175,7 +175,8 @@ def _action(*project_types: str, **deco_kwargs) -> Callable:     # Callable[[Cal
     def _deco(fun):
         # global REGISTERED_ACTIONS
         method_of = stack_var('__qualname__')
-        assert not deco_kwargs.get('local', False) or not method_of, "local=True spec key not allowed for remote action"
+        if 'local_action' not in deco_kwargs:
+            deco_kwargs['local_action'] = not method_of
         REGISTERED_ACTIONS[(method_of + "." if method_of else "") + fun.__name__] = {
             'project_types': project_types, 'docstring': fun.__doc__, **deco_kwargs}
 
@@ -579,7 +580,7 @@ def _act_spec() -> ActionSpecification:
         ACTION_NAME,
         REGISTERED_ACTIONS.get(
             (REMOTE_REPO and REMOTE_REPO.__class__.__name__ or REMOTE_CLASS_NAMES[_repo_domain()]) + "." + ACTION_NAME,
-            {'local': True}))
+            {'local_action': True}))
 
 
 def _available_actions() -> Set[str]:
@@ -1175,14 +1176,14 @@ def _prepare_act_exec():
         project_path = pdv_str(INI_PDV, 'project_path')
         cur_branch = pdv_str(INI_PDV, 'git_current_branch')
         if cur_branch != MAIN_BRANCH:
-            cae.po(f"   -- current working branch of local project at '{project_path}' is '{cur_branch}'")
+            cae.po(f"   -- current working branch of project at '{project_path}' is '{cur_branch}'")
         changed = pdv_val(INI_PDV, 'git_uncommitted_files')
         if changed:
             cae.po(f"   -- '{project_path}' has {len(changed)} uncommitted files: {changed}")
         extra_msg += f" ({project_path})"
 
     act_spec = _act_spec()
-    if not act_spec.get('local', False):
+    if not act_spec['local_action']:
         personal_token = cae.get_option('gitToken') or input("...... enter personal access token:")
         if not personal_token:
             _exit_error(36, f"****  empty git host personal access token '{personal_token}'")
@@ -1655,7 +1656,7 @@ class GitlabCom(_RemoteHost):
 # --------------- local and remote action functions -------------------------------------------------------------------
 
 
-@_action(APP_PRJ, MODULE_PRJ, PACKAGE_PRJ, ROOT_PRJ, local=True)
+@_action(APP_PRJ, MODULE_PRJ, PACKAGE_PRJ, ROOT_PRJ)
 def bump_version():
     """ increment project version. """
     old_version = pdv_str(INI_PDV, 'package_version')
@@ -1681,7 +1682,7 @@ def check_integrity():
     cae.po(f"  === {pdv_str(INI_PDV, 'project_name')} successfully passed integrity checks")
 
 
-@_action(ROOT_PRJ, arg_names=((ARG_ALL, ), ('portions-sets-expr', ), ('portion-names' + ARG_MULTIPLES, )), local=True)
+@_action(ROOT_PRJ, arg_names=((ARG_ALL, ), ('portions-sets-expr', ), ('portion-names' + ARG_MULTIPLES, )))
 def check_portions_integrity():
     """ run integrity checks for the specified portions of a namespace. """
     portions_vars = pdv_val(INI_PDV, 'portions_project_vars')
@@ -1695,7 +1696,7 @@ def check_portions_integrity():
         cae.po(f"  === {pdv_str(por_pdv, 'project_name')} successfully passed integrity checks")
 
 
-@_action(PARENT_PRJ, arg_names=(('--domain', '--group', '--package'), ), local=True)
+@_action(PARENT_PRJ, arg_names=(('--domain', '--group', '--package'), ))
 def clone_project():
     """ clone remote repo to the local machine. """
     repo_root = f"{pdv_str(INI_PDV, 'REPO_HOST_PROTOCOL')}{cae.get_option('domain')}/{cae.get_option('group')}"
@@ -1707,8 +1708,7 @@ def clone_project():
 @_action(ROOT_PRJ,
          arg_names=(('--domain', '--group', '--package', ARG_ALL),
                     ('--domain', '--group', '--package', 'portions-sets-expr'),
-                    ('--domain', '--group', '--package', 'portion-names' + ARG_MULTIPLES)),
-         local=True)
+                    ('--domain', '--group', '--package', 'portion-names' + ARG_MULTIPLES)))
 def clone_portions():
     """ clone specified namespace portion repos to the local machine. """
     repo_root = f"{pdv_str(INI_PDV, 'REPO_HOST_PROTOCOL')}{cae.get_option('domain')}/{cae.get_option('group')}"
@@ -1720,7 +1720,7 @@ def clone_portions():
         cae.po(f"   == {package_name} cloned from {repo_root} into project path {project_path}")
 
 
-@_action(APP_PRJ, MODULE_PRJ, PACKAGE_PRJ, ROOT_PRJ, local=True)
+@_action(APP_PRJ, MODULE_PRJ, PACKAGE_PRJ, ROOT_PRJ)
 def commit_project():
     """ commit changes to local repo using the prepared commit message in :data:`COMMIT_MSG_FILE_NAME`. """
     _git_add(INI_PDV)
@@ -1728,7 +1728,7 @@ def commit_project():
     cae.po(f"  === {pdv_str(INI_PDV, 'project_name')} successfully committed")
 
 
-@_action(ROOT_PRJ, arg_names=((ARG_ALL, ), ('portions-sets-expr', ), ('portion-names' + ARG_MULTIPLES, )), local=True)
+@_action(ROOT_PRJ, arg_names=((ARG_ALL, ), ('portions-sets-expr', ), ('portion-names' + ARG_MULTIPLES, )))
 def commit_portions():
     """ commit changes to the portions of a namespace using the prepared message in :data:`COMMIT_MSG_FILE_NAME`. """
     portions_vars = pdv_val(INI_PDV, 'portions_project_vars')
@@ -1740,7 +1740,7 @@ def commit_portions():
     cae.po(f"  === committed {len(PORTIONS_ARGS)} {pdv_str(INI_PDV, 'namespace_name')} portions: {PORTIONS_ARGS}")
 
 
-@_action(ROOT_PRJ, arg_names=((ARG_ALL, ), ('portions-sets-expr', ), ('portion-names' + ARG_MULTIPLES, )), local=True)
+@_action(ROOT_PRJ, arg_names=((ARG_ALL, ), ('portions-sets-expr', ), ('portion-names' + ARG_MULTIPLES, )))
 def install_portions_editable():
     """ install namespace portions as editable on local machine. """
     parent_path = os.path.dirname(pdv_str(INI_PDV, 'project_path'))
@@ -1753,31 +1753,31 @@ def install_portions_editable():
     cae.po(f"  === installed {len(PORTIONS_ARGS)} {pdv_str(INI_PDV, 'namespace_name')} portions: {PORTIONS_ARGS}")
 
 
-@_action(arg_names=(('--path', ), ('--package', )), local=True)
+@_action(arg_names=(('--path', ), ('--package', )))
 def new_app():
     """ create or complete/renew an gui app project. """
     _renew_project(APP_PRJ)
 
 
-@_action(arg_names=(('--path', ), ('--package', )), local=True)
+@_action(arg_names=(('--path', ), ('--package', )))
 def new_module():
     """ create or complete/renew module project. """
     _renew_project(MODULE_PRJ)
 
 
-@_action(arg_names=(('--path', ), ('--package', )), local=True)
+@_action(arg_names=(('--path', ), ('--package', )))
 def new_package():
     """ create or complete/renew package project. """
     _renew_project(PACKAGE_PRJ)
 
 
-@_action(arg_names=(('--path', ), ('--package', )), local=True)
+@_action(arg_names=(('--path', ), ('--package', )))
 def new_namespace_root():
     """ create or complete/renew namespace root package. """
     _renew_project(ROOT_PRJ)
 
 
-@_action(APP_PRJ, MODULE_PRJ, PACKAGE_PRJ, ROOT_PRJ, local=True)
+@_action(APP_PRJ, MODULE_PRJ, PACKAGE_PRJ, ROOT_PRJ)
 def prepare_commit():
     """ run code checks and prepare :data:`COMMIT_MSG_FILE_NAME` for the commit of a single project/package. """
     check_integrity()
@@ -1786,7 +1786,7 @@ def prepare_commit():
     cae.po("  === commit prepared")
 
 
-@_action(ROOT_PRJ, arg_names=((ARG_ALL, ), ('portions-sets-expr', ), ('portion-names' + ARG_MULTIPLES, )), local=True)
+@_action(ROOT_PRJ, arg_names=((ARG_ALL, ), ('portions-sets-expr', ), ('portion-names' + ARG_MULTIPLES, )))
 def prepare_portions_commit():
     """ run code checks and prepare :data:`COMMIT_MSG_FILE_NAME` for the commit of portions of a namespace. """
     check_portions_integrity()
@@ -1800,7 +1800,7 @@ def prepare_portions_commit():
     cae.po(f"  === prepared commit of {len(PORTIONS_ARGS)} namespace portions: {PORTIONS_ARGS}")
 
 
-@_action(local=True)
+@_action()
 def show_actions():
     """ get info of available/registered/implemented actions of the specified/current project and remote. """
     compact = not cae.get_option('verbose')
@@ -1837,7 +1837,7 @@ def show_actions():
         cae.po(f"      {', '.join(_.replace('_', '-') for _ in actions if not _act_callable(_)) or '<none>'}")
 
 
-@_action(local=True)
+@_action()
 def show_status(pdv: Optional[PdvType] = None):
     """ show git status of the specified/current project and remote. """
     if pdv is None:
@@ -1852,7 +1852,7 @@ def show_status(pdv: Optional[PdvType] = None):
     cae.po(_git_status(pdv))
 
 
-@_action(ROOT_PRJ, arg_names=((ARG_ALL, ), ('portions-sets-expr', ), ('portion-names' + ARG_MULTIPLES, )), local=True)
+@_action(ROOT_PRJ, arg_names=((ARG_ALL, ), ('portions-sets-expr', ), ('portion-names' + ARG_MULTIPLES, )))
 def show_portions_status():
     """ run integrity checks for the specified portions of a namespace. """
     portions_vars = pdv_val(INI_PDV, 'portions_project_vars')
